/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
  CODE_FOR_addsi3 = 3,
  CODE_FOR_addvsi3 = 18,
  CODE_FOR_addvdi3 = 19,
  CODE_FOR_negsi2 = 20,
  CODE_FOR_negdi2 = 21,
  CODE_FOR_negvsi2 = 23,
  CODE_FOR_negvdi2 = 24,
  CODE_FOR_subsi3 = 25,
  CODE_FOR_subdi3 = 26,
  CODE_FOR_subvsi3 = 32,
  CODE_FOR_subvdi3 = 33,
  CODE_FOR_mulsi3 = 34,
  CODE_FOR_muldi3 = 35,
  CODE_FOR_mulvsi3 = 37,
  CODE_FOR_mulvdi3 = 38,
  CODE_FOR_umuldi3_highpart = 39,
  CODE_FOR_anddi3 = 47,
  CODE_FOR_zero_extendqihi2 = 48,
  CODE_FOR_zero_extendqisi2 = 49,
  CODE_FOR_zero_extendqidi2 = 50,
  CODE_FOR_zero_extendhisi2 = 51,
  CODE_FOR_zero_extendhidi2 = 52,
  CODE_FOR_zero_extendsidi2 = 53,
  CODE_FOR_andnotsi3 = 54,
  CODE_FOR_andnotdi3 = 55,
  CODE_FOR_iordi3 = 57,
  CODE_FOR_one_cmpldi2 = 59,
  CODE_FOR_xordi3 = 63,
  CODE_FOR_clzdi2 = 66,
  CODE_FOR_ctzdi2 = 67,
  CODE_FOR_popcountdi2 = 68,
  CODE_FOR_ashldi3 = 69,
  CODE_FOR_ashlsi3 = 70,
  CODE_FOR_lshrdi3 = 72,
  CODE_FOR_ashrdi3 = 73,
  CODE_FOR_extendqihi2 = 74,
  CODE_FOR_extendqisi2 = 75,
  CODE_FOR_extendhisi2 = 77,
  CODE_FOR_extxl = 80,
  CODE_FOR_extqh = 83,
  CODE_FOR_extwh = 84,
  CODE_FOR_extlh = 85,
  CODE_FOR_insbl_const = 86,
  CODE_FOR_inswl_const = 87,
  CODE_FOR_insll_const = 88,
  CODE_FOR_insbl = 89,
  CODE_FOR_inswl = 90,
  CODE_FOR_insll = 91,
  CODE_FOR_insql = 92,
  CODE_FOR_insxh = 94,
  CODE_FOR_mskxl = 95,
  CODE_FOR_mskxh = 96,
  CODE_FOR_abssf2 = 98,
  CODE_FOR_absdf2 = 99,
  CODE_FOR_negsf2 = 103,
  CODE_FOR_negdf2 = 104,
  CODE_FOR_copysignsf3 = 106,
  CODE_FOR_copysigndf3 = 107,
  CODE_FOR_addsf3 = 110,
  CODE_FOR_adddf3 = 111,
  CODE_FOR_subsf3 = 114,
  CODE_FOR_subdf3 = 115,
  CODE_FOR_mulsf3 = 119,
  CODE_FOR_muldf3 = 120,
  CODE_FOR_divsf3 = 123,
  CODE_FOR_divdf3 = 124,
  CODE_FOR_sqrtsf2 = 128,
  CODE_FOR_sqrtdf2 = 129,
  CODE_FOR_floatdisf2 = 137,
  CODE_FOR_floatdidf2 = 140,
  CODE_FOR_truncdfsf2 = 145,
  CODE_FOR_smaxqi3 = 161,
  CODE_FOR_sminqi3 = 162,
  CODE_FOR_umaxqi3 = 163,
  CODE_FOR_uminqi3 = 164,
  CODE_FOR_smaxhi3 = 165,
  CODE_FOR_sminhi3 = 166,
  CODE_FOR_umaxhi3 = 167,
  CODE_FOR_uminhi3 = 168,
  CODE_FOR_blockage = 201,
  CODE_FOR_jump = 202,
  CODE_FOR_indirect_jump = 204,
  CODE_FOR_imb = 206,
  CODE_FOR_trap = 207,
  CODE_FOR_get_thread_pointerdi = 208,
  CODE_FOR_movdi_er_high_g = 215,
  CODE_FOR_movdi_er_tlsgd = 216,
  CODE_FOR_movdi_er_tlsldm = 217,
  CODE_FOR_force_movdi = 221,
  CODE_FOR_reload_inqi_aligned = 225,
  CODE_FOR_reload_inhi_aligned = 226,
  CODE_FOR_reload_outqi_aligned = 227,
  CODE_FOR_reload_outhi_aligned = 228,
  CODE_FOR_smaxv8qi3 = 232,
  CODE_FOR_sminv8qi3 = 233,
  CODE_FOR_umaxv8qi3 = 234,
  CODE_FOR_uminv8qi3 = 235,
  CODE_FOR_smaxv4hi3 = 236,
  CODE_FOR_sminv4hi3 = 237,
  CODE_FOR_umaxv4hi3 = 238,
  CODE_FOR_uminv4hi3 = 239,
  CODE_FOR_one_cmplv8qi2 = 240,
  CODE_FOR_one_cmplv4hi2 = 241,
  CODE_FOR_one_cmplv2si2 = 242,
  CODE_FOR_andv8qi3 = 243,
  CODE_FOR_andv4hi3 = 244,
  CODE_FOR_andv2si3 = 245,
  CODE_FOR_iorv8qi3 = 249,
  CODE_FOR_iorv4hi3 = 250,
  CODE_FOR_iorv2si3 = 251,
  CODE_FOR_xorv8qi3 = 255,
  CODE_FOR_xorv4hi3 = 256,
  CODE_FOR_xorv2si3 = 257,
  CODE_FOR_prologue_stack_probe_loop = 261,
  CODE_FOR_prologue_mcount = 267,
  CODE_FOR_init_fp = 268,
  CODE_FOR_builtin_longjmp_internal = 269,
   CODE_FOR_arg_home = CODE_FOR_nothing,
  CODE_FOR_prefetch = 274,
  CODE_FOR_trapb = 275,
  CODE_FOR_nop = 276,
  CODE_FOR_fnop = 277,
  CODE_FOR_unop = 278,
  CODE_FOR_realign = 279,
  CODE_FOR_builtin_cmpbge = 280,
  CODE_FOR_builtin_amask = 283,
  CODE_FOR_builtin_implver = 284,
  CODE_FOR_builtin_rpcc = 285,
  CODE_FOR_builtin_perr = 286,
  CODE_FOR_load_locked_si = 292,
  CODE_FOR_load_locked_di = 293,
  CODE_FOR_store_conditional_si = 294,
  CODE_FOR_store_conditional_di = 295,
  CODE_FOR_atomic_compare_and_swapqi_1 = 298,
  CODE_FOR_atomic_compare_and_swaphi_1 = 299,
  CODE_FOR_atomic_exchangesi = 300,
  CODE_FOR_atomic_exchangedi = 301,
  CODE_FOR_atomic_exchangeqi_1 = 302,
  CODE_FOR_atomic_exchangehi_1 = 303,
  CODE_FOR_atomic_addsi = 304,
  CODE_FOR_atomic_subsi = 305,
  CODE_FOR_atomic_orsi = 306,
  CODE_FOR_atomic_xorsi = 307,
  CODE_FOR_atomic_andsi = 308,
  CODE_FOR_atomic_adddi = 309,
  CODE_FOR_atomic_subdi = 310,
  CODE_FOR_atomic_ordi = 311,
  CODE_FOR_atomic_xordi = 312,
  CODE_FOR_atomic_anddi = 313,
  CODE_FOR_atomic_nandsi = 314,
  CODE_FOR_atomic_nanddi = 315,
  CODE_FOR_atomic_fetch_addsi = 316,
  CODE_FOR_atomic_fetch_subsi = 317,
  CODE_FOR_atomic_fetch_orsi = 318,
  CODE_FOR_atomic_fetch_xorsi = 319,
  CODE_FOR_atomic_fetch_andsi = 320,
  CODE_FOR_atomic_fetch_adddi = 321,
  CODE_FOR_atomic_fetch_subdi = 322,
  CODE_FOR_atomic_fetch_ordi = 323,
  CODE_FOR_atomic_fetch_xordi = 324,
  CODE_FOR_atomic_fetch_anddi = 325,
  CODE_FOR_atomic_fetch_nandsi = 326,
  CODE_FOR_atomic_fetch_nanddi = 327,
  CODE_FOR_atomic_add_fetchsi = 328,
  CODE_FOR_atomic_sub_fetchsi = 329,
  CODE_FOR_atomic_or_fetchsi = 330,
  CODE_FOR_atomic_xor_fetchsi = 331,
  CODE_FOR_atomic_and_fetchsi = 332,
  CODE_FOR_atomic_add_fetchdi = 333,
  CODE_FOR_atomic_sub_fetchdi = 334,
  CODE_FOR_atomic_or_fetchdi = 335,
  CODE_FOR_atomic_xor_fetchdi = 336,
  CODE_FOR_atomic_and_fetchdi = 337,
  CODE_FOR_atomic_nand_fetchsi = 338,
  CODE_FOR_atomic_nand_fetchdi = 339,
  CODE_FOR_call_value_osf_tlsgd = 345,
  CODE_FOR_call_value_osf_tlsldm = 346,
  CODE_FOR_extendsidi2 = 350,
  CODE_FOR_adddi3 = 351,
  CODE_FOR_umulditi3 = 352,
  CODE_FOR_divsi3 = 353,
  CODE_FOR_modsi3 = 354,
  CODE_FOR_udivsi3 = 355,
  CODE_FOR_umodsi3 = 356,
  CODE_FOR_divdi3 = 357,
  CODE_FOR_moddi3 = 358,
  CODE_FOR_udivdi3 = 359,
  CODE_FOR_umoddi3 = 360,
  CODE_FOR_ffsdi2 = 361,
  CODE_FOR_bswapsi2 = 362,
  CODE_FOR_bswapdi2 = 363,
  CODE_FOR_extendqidi2 = 364,
  CODE_FOR_extendhidi2 = 365,
  CODE_FOR_unaligned_extendqidi = 366,
  CODE_FOR_unaligned_extendhidi = 367,
  CODE_FOR_abstf2 = 368,
  CODE_FOR_negtf2 = 369,
  CODE_FOR_addtf3 = 370,
  CODE_FOR_subtf3 = 371,
  CODE_FOR_multf3 = 372,
  CODE_FOR_divtf3 = 373,
  CODE_FOR_fix_truncdfdi2 = 374,
  CODE_FOR_fixuns_truncdfdi2 = 375,
  CODE_FOR_fix_truncsfdi2 = 376,
  CODE_FOR_fixuns_truncsfdi2 = 377,
  CODE_FOR_fix_trunctfdi2 = 378,
  CODE_FOR_fixuns_trunctfdi2 = 379,
  CODE_FOR_floatditf2 = 380,
  CODE_FOR_floatunsdisf2 = 381,
  CODE_FOR_floatunsdidf2 = 382,
  CODE_FOR_floatunsditf2 = 383,
  CODE_FOR_extendsfdf2 = 384,
  CODE_FOR_extendsftf2 = 385,
  CODE_FOR_extenddftf2 = 386,
  CODE_FOR_trunctfdf2 = 387,
  CODE_FOR_trunctfsf2 = 388,
  CODE_FOR_absdi2 = 389,
  CODE_FOR_absdi2_same = 390,
  CODE_FOR_absdi2_diff = 391,
  CODE_FOR_smaxdi3 = 392,
  CODE_FOR_smindi3 = 393,
  CODE_FOR_umaxdi3 = 394,
  CODE_FOR_umindi3 = 395,
  CODE_FOR_smaxdf3 = 396,
  CODE_FOR_smindf3 = 397,
  CODE_FOR_smaxsf3 = 398,
  CODE_FOR_sminsf3 = 399,
  CODE_FOR_cbranchdf4 = 400,
  CODE_FOR_cbranchtf4 = 401,
  CODE_FOR_cbranchdi4 = 402,
  CODE_FOR_cstoredf4 = 403,
  CODE_FOR_cstoretf4 = 404,
  CODE_FOR_cstoredi4 = 405,
  CODE_FOR_movsicc = 406,
  CODE_FOR_movdicc = 407,
  CODE_FOR_movsfcc = 408,
  CODE_FOR_movdfcc = 409,
  CODE_FOR_call = 410,
  CODE_FOR_sibcall = 411,
  CODE_FOR_call_osf = 412,
  CODE_FOR_call_vms = 413,
  CODE_FOR_call_value = 414,
  CODE_FOR_sibcall_value = 415,
  CODE_FOR_call_value_osf = 416,
  CODE_FOR_call_value_vms = 417,
  CODE_FOR_untyped_call = 418,
  CODE_FOR_return = 419,
  CODE_FOR_tablejump = 420,
  CODE_FOR_clear_cache = 421,
  CODE_FOR_set_thread_pointerdi = 422,
   CODE_FOR_builtin_establish_vms_condition_handler = CODE_FOR_nothing,
   CODE_FOR_builtin_revert_vms_condition_handler = CODE_FOR_nothing,
  CODE_FOR_movsf = 423,
  CODE_FOR_movdf = 424,
  CODE_FOR_movtf = 425,
  CODE_FOR_movsi = 426,
  CODE_FOR_movdi = 427,
  CODE_FOR_movti = 428,
  CODE_FOR_aligned_loadqi = 429,
  CODE_FOR_aligned_loadhi = 430,
  CODE_FOR_unaligned_loadqi = 431,
  CODE_FOR_unaligned_loadhi = 432,
  CODE_FOR_aligned_store = 433,
  CODE_FOR_aligned_store_safe_bwa = 434,
  CODE_FOR_unaligned_storeqi = 435,
  CODE_FOR_unaligned_storehi = 436,
  CODE_FOR_unaligned_storeqi_safe_bwa = 437,
  CODE_FOR_unaligned_storehi_safe_bwa = 438,
  CODE_FOR_movqi = 439,
  CODE_FOR_movhi = 440,
  CODE_FOR_movcqi = 441,
  CODE_FOR_reload_inqi = 442,
  CODE_FOR_reload_inhi = 443,
  CODE_FOR_reload_incqi = 444,
  CODE_FOR_reload_outqi = 445,
  CODE_FOR_reload_outhi = 446,
  CODE_FOR_reload_outcqi = 447,
  CODE_FOR_reload_outqi_safe_bwa = 448,
  CODE_FOR_reload_outhi_safe_bwa = 449,
  CODE_FOR_reload_outcqi_safe_bwa = 450,
  CODE_FOR_reload_outqi_unaligned_safe_bwa = 451,
  CODE_FOR_reload_outhi_unaligned_safe_bwa = 452,
  CODE_FOR_movv8qi = 453,
  CODE_FOR_movv4hi = 454,
  CODE_FOR_movv2si = 455,
  CODE_FOR_movmisalignv8qi = 456,
  CODE_FOR_movmisalignv4hi = 457,
  CODE_FOR_movmisalignv2si = 458,
  CODE_FOR_vec_shl_v8qi = 459,
  CODE_FOR_vec_shl_v4hi = 460,
  CODE_FOR_vec_shl_v2si = 461,
  CODE_FOR_vec_shr_v8qi = 462,
  CODE_FOR_vec_shr_v4hi = 463,
  CODE_FOR_vec_shr_v2si = 464,
  CODE_FOR_extvmisaligndi = 465,
  CODE_FOR_extzvdi = 466,
  CODE_FOR_extzvmisaligndi = 467,
  CODE_FOR_insvmisaligndi = 468,
  CODE_FOR_cpymemqi = 469,
   CODE_FOR_cpymemdi = CODE_FOR_nothing,
  CODE_FOR_setmemqi = 470,
   CODE_FOR_setmemdi = CODE_FOR_nothing,
  CODE_FOR_stack_probe_internal = 471,
  CODE_FOR_allocate_stack = 472,
  CODE_FOR_prologue = 473,
  CODE_FOR_prologue_ldgp = 474,
  CODE_FOR_epilogue = 475,
  CODE_FOR_sibcall_epilogue = 476,
  CODE_FOR_builtin_longjmp = 477,
  CODE_FOR_builtin_setjmp_receiver = 478,
  CODE_FOR_exception_receiver = 479,
   CODE_FOR_nonlocal_goto_receiver = CODE_FOR_nothing,
  CODE_FOR_extbl = 480,
  CODE_FOR_extwl = 481,
  CODE_FOR_extll = 482,
  CODE_FOR_extql = 483,
  CODE_FOR_builtin_insbl = 484,
  CODE_FOR_builtin_inswl = 485,
  CODE_FOR_builtin_insll = 486,
  CODE_FOR_inswh = 487,
  CODE_FOR_inslh = 488,
  CODE_FOR_insqh = 489,
  CODE_FOR_mskbl = 490,
  CODE_FOR_mskwl = 491,
  CODE_FOR_mskll = 492,
  CODE_FOR_mskql = 493,
  CODE_FOR_mskwh = 494,
  CODE_FOR_msklh = 495,
  CODE_FOR_mskqh = 496,
  CODE_FOR_builtin_zap = 497,
  CODE_FOR_builtin_zapnot = 498,
  CODE_FOR_builtin_minub8 = 499,
  CODE_FOR_builtin_minsb8 = 500,
  CODE_FOR_builtin_minuw4 = 501,
  CODE_FOR_builtin_minsw4 = 502,
  CODE_FOR_builtin_maxub8 = 503,
  CODE_FOR_builtin_maxsb8 = 504,
  CODE_FOR_builtin_maxuw4 = 505,
  CODE_FOR_builtin_maxsw4 = 506,
  CODE_FOR_builtin_pklb = 507,
  CODE_FOR_builtin_pkwb = 508,
  CODE_FOR_builtin_unpkbl = 509,
  CODE_FOR_builtin_unpkbw = 510,
  CODE_FOR_memory_barrier = 511,
  CODE_FOR_atomic_compare_and_swapsi = 512,
  CODE_FOR_atomic_compare_and_swapdi = 513,
  CODE_FOR_atomic_compare_and_swapqi = 514,
  CODE_FOR_atomic_compare_and_swaphi = 515,
  CODE_FOR_atomic_exchangeqi = 516,
  CODE_FOR_atomic_exchangehi = 517
};

const unsigned int NUM_INSN_CODES = 518;
#endif /* GCC_INSN_CODES_H */
